/*
   PIC32-PINGUINO
   Blinks both LEDs (Green and Yellow)
   using an interrupt routine
   on Timer1 overflow
   
    If you have any questions, email
    support@olimex.com
    
    OLIMEX, JULY 2012
    http://www.olimex.com
*/

#if ( defined(PIC32_PINGUINO_OTG) || defined(PIC32_PINGUINO) || defined(PIC32_PINGUINO_MICRO) )

	//Definitions for 
	// -- PIC32-PINGUINO
	// -- PIC32-PINGUINO-OTG
	// -- PIC32-PINGUINO-MICRO
		
	#define BUTTON1INIT TRISDbits.TRISD0 = 1
	
	//YELLOW LED is D1
	#define YLEDINIT   TRISDCLR = 0x02;
	#define YLED1      PORTDSET = 0x02;
	#define YLED0      PORTDCLR = 0x02;
	#define YLEDSWITCH PORTD   ^= 0x02;
	
	//GREEN LED is G6
	#define GLEDINIT  	 TRISGCLR = 0x40;
	#define GLED1 		    PORTGSET = 0x40;
	#define GLED0 		    PORTGCLR = 0x40;
	#define GLEDSWITCH   PORTG   ^= 0x40;
	
	#define YELLOW 0
	#define GREEN  1
	#define BOTH   2
#endif


	// Connect the wrapper to vector 4 (Timer1 overflow)
	void ISR_wrapper_vector_4(void) __attribute__ ((section (".vector_4")));

	// The wrapper calls the "Tmr1Interrupt" function
	// each time an interrupt occurs
	void ISR_wrapper_vector_4(void) { Tmr1Interrupt(); }

	//We declare the function as an interrupt routine
	void Tmr1Interrupt(void) __attribute__ ((interrupt));

 // This code will be executed each time an interrupt occurs
	void Tmr1Interrupt(void)
	{
     T1CONCLR = (1<<15);  //Stop Timer 1
     
			GLEDSWITCH;
     YLEDSWITCH;
     
     // Start Timer 1 again
	    init_timer1();
	}
	
	// configure timer 1
	void init_timer1(void)
	{
		IntConfigureSystem(INT_SYSTEM_CONFIG_MULT_VECTOR);	// interrupt mode (interrupt.c)
		T1CON=0;			    // reset timer 1 configuration
		TMR1=0;				    // reset timer 1 counter register
		PR1=0x9896;			// define the period; combined with the prescaler equals ~ 4 interrupts for 1s
		IPC1SET=0x7;		// select interrupt priority and sub-priority
		IFS0CLR=0x10;		// clear interrupt flag
		IEC0SET=0x10;		// enable timer 1 interrupt
		T1CONSET=0x30;	  	// set prescaler to 256
		T1CONSET=0x8000; 	// turn TIMER1 ON
	}

	
/* ****************************************** */

void setup() {
    // put your setup code here, to run once:
    YLEDINIT;
    GLEDINIT;
    YLED0;
    GLED0;
    
    init_timer1();
    }

void loop() {}


